==> breeze-5.5.95.tar.xz: breeze-5.5.95/kstyle/animations/breezeanimation.h <==
#ifndef breezeanimation_h
#define breezeanimation_h
/*************************************************************************
 * Copyright (C) 2014 by Hugo Pereira Da Costa <hugo.pereira@free.fr>    *
 *                                                                       *
 * This program is free software; you can redistribute it and/or modify  *
 * it under the terms of the GNU General Public License as published by  *
 * the Free Software Foundation; either version 2 of the License, or     *
 * (at your option) any later version.                                   *
 *                                                                       *
 * This program is distributed in the hope that it will be useful,       *
 * but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 * GNU General Public License for more details.                          *
 *                                                                       *
 * You should have received a copy of the GNU General Public License     *
 * along with this program; if not, write to the                         *
 * Free Software Foundation, Inc.,                                       *
 * 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA .        *
 *************************************************************************/

#include "breeze.h"

#include <QPropertyAnimation>
#include <QVariant>

namespace Breeze
{

    class Animation: public QPropertyAnimation
    {

        Q_OBJECT

        public:

        //* convenience
        using Pointer = WeakPointer<Animation>;

        //* constructor
        Animation( int duration, QObject* parent ):
            QPropertyAnimation( parent )
        { setDuration( duration ); }

        //* destructor
        virtual ~Animation( void )
        {}

        //* true if running
        bool isRunning( void ) const
        { return state() == Animation::Running; }

        //* restart
        void restart( void )
        {
            if( isRunning() ) stop();
            start();
        }

    };

}

#endif

==> breeze_5.9.4.orig.tar.xz: breeze-5.9.4/kstyle/animations/breezeanimation.h <==
#ifndef breezeanimation_h
#define breezeanimation_h
/*************************************************************************
 * Copyright (C) 2014 by Hugo Pereira Da Costa <hugo.pereira@free.fr>    *
 *                                                                       *
 * This program is free software; you can redistribute it and/or modify  *
 * it under the terms of the GNU General Public License as published by  *
 * the Free Software Foundation; either version 2 of the License, or     *
 * (at your option) any later version.                                   *
 *                                                                       *
 * This program is distributed in the hope that it will be useful,       *
 * but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 * GNU General Public License for more details.                          *
 *                                                                       *
 * You should have received a copy of the GNU General Public License     *
 * along with this program; if not, write to the                         *
 * Free Software Foundation, Inc.,                                       *
 * 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA .        *
 *************************************************************************/

#include "breeze.h"

#include <QPropertyAnimation>
#include <QVariant>

namespace Breeze
{

    class Animation: public QPropertyAnimation
    {

        Q_OBJECT

        public:

        //* convenience
        using Pointer = WeakPointer<Animation>;

        //* constructor
        Animation( int duration, QObject* parent ):
            QPropertyAnimation( parent )
        { setDuration( duration ); }

        //* destructor
        virtual ~Animation( void ) = default;

        //* true if running
        bool isRunning( void ) const
        { return state() == Animation::Running; }

        //* restart
        void restart( void )
        {
            if( isRunning() ) stop();
            start();
        }

    };

}

#endif
